<!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>ChatRoomWidget</name>
    <message>
        <source>Choose a room to send messages or enter a command...</source>
        <translation>Wybierz pokój do wysyłania wiadomości lub wprowadź polecenie…</translation>
    </message>
    <message>
        <source>There&apos;s nothing to send</source>
        <translation>Nie ma niczego do przesłania</translation>
    </message>
    <message>
        <source>/join argument doesn&apos;t look like a room ID or alias</source>
        <translation>/join nie wygląda jak identyfikator pokoju lub alias</translation>
    </message>
    <message>
        <source>Sending a farewell message is not supported yet. If you intended to leave another room, switch to it and type /leave there.</source>
        <translation>Wysyłanie wiadomości pożegnalnej nie jest jeszcze obsługiwane. Jeśli chcesz opuścić inny pokój, przełącz się do niego i wpisz tam /leave.</translation>
    </message>
    <message>
        <source>/forget must be followed by the room id/alias, even for the current room</source>
        <translation>/forget musi poprzedzać identyfikator pokoju/alias, nawet dla bieżącego pomieszczenia</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a room id or alias</source>
        <translation>%1 nie wygląda jak identyfikator pokoju lub alias</translation>
    </message>
    <message>
        <source>/invite &lt;memberId&gt;</source>
        <translation>/invite &lt;memberId&gt;</translation>
    </message>
    <message>
        <source>/%1 &lt;userId&gt; &lt;reason&gt;</source>
        <translation>/%1 &lt;userId&gt; &lt;reason&gt;</translation>
    </message>
    <message>
        <source>%1 is not a member of this room</source>
        <translation>%1 nie jest członkiem tego pokoju</translation>
    </message>
    <message>
        <source>/unban &lt;userId&gt;</source>
        <translation>/unban &lt;userId&gt;</translation>
    </message>
    <message>
        <source>/unban argument doesn&apos;t look like a user ID</source>
        <translation>/unban nie wygląda jak identyfikator użytkownika</translation>
    </message>
    <message>
        <source>/ignore &lt;userId&gt;</source>
        <translation>/ignore &lt;userId&gt;</translation>
    </message>
    <message>
        <source>/ignore argument doesn&apos;t look like a user ID</source>
        <translation>/ignore nie wygląda jak identyfikator użytkownika</translation>
    </message>
    <message>
        <source>Couldn&apos;t find user %1 on the server</source>
        <translation>Nie można znaleźć użytkownika %1 na serwerze</translation>
    </message>
    <message>
        <source>/me needs an argument</source>
        <translation>/me potrzebuje argumentu</translation>
    </message>
    <message>
        <source>/notice needs an argument</source>
        <translation>/notice potrzebuje argumentu</translation>
    </message>
    <message>
        <source>/%1 &lt;memberId&gt; &lt;message&gt;</source>
        <translation>/%1 &lt;memberId&gt; &lt;message&gt;</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t seem to have joined room %2</source>
        <translation>%1 najwyraźniej nie dołączył do pokoju %2</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user id or room alias</source>
        <translation>%1 nie wygląda jak identyfikator użytkownika lub alias pokoju</translation>
    </message>
    <message>
        <source>/%1 &lt;memberId&gt;</source>
        <translation>/%1 &lt;memberId&gt;</translation>
    </message>
    <message>
        <source>Attach</source>
        <translation>Załącz</translation>
    </message>
    <message>
        <source>Attach file</source>
        <translation>Załącz plik</translation>
    </message>
    <message>
        <source>Add a message to the file or just push Enter</source>
        <translation>Dodaj wiadomość do pliku lub po prostu naciśnij Enter</translation>
    </message>
    <message>
        <source>Attaching %1</source>
        <translation>Załączanie %1</translation>
    </message>
    <message>
        <source>Attaching cancelled</source>
        <translation>Załączanie anulowano</translation>
    </message>
    <message>
        <source>There&apos;s no such /command outside of room.</source>
        <translation>Nie ma takiego /polecenia poza pokojem.</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user id</source>
        <translation>%1 nie wygląda jak identyfikator użytkownika</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user ID</source>
        <translation>%1 nie wygląda jak identyfikator użytkownika</translation>
    </message>
    <message>
        <source>You should select a room to send messages.</source>
        <translation>Powinieneś/Powinnaś wybrać pokój do wysyłania wiadomości.</translation>
    </message>
    <message>
        <source>Send a message (over %1) or enter a command...</source>
        <translation>Wyślij wiadomość (poprzez %1) lub wprowadź polecenie…</translation>
    </message>
    <message>
        <source>No completions</source>
        <translation>Brak dokończeń</translation>
    </message>
    <message numerus="yes">
        <source>%Ln more completions</source>
        <translation>
            <numerusform>%Ln dokończenie więcej</numerusform>
            <numerusform>%Ln dokończenia więcej</numerusform>
            <numerusform>%Ln dokończeń więcej</numerusform>
            <numerusform>%Ln dokończeń więcej</numerusform>
        </translation>
    </message>
    <message>
        <source>Next completion:</source>
        <translation>Następne dokończenie</translation>
    </message>
    <message>
        <source>Currently typing:</source>
        <translation>Obecnie pisze:</translation>
    </message>
    <message>
        <source>%L1 more</source>
        <translation>%L1 więcej</translation>
    </message>
</context>
<context>
    <name>CreateRoomDialog</name>
    <message>
        <source>Create room</source>
        <translation>Utwórz pokój</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Invite user(s)</source>
        <translation>Zaproś użytkownika(-ów)</translation>
    </message>
    <message>
        <source>Creating the room, please wait</source>
        <translation>Tworzę pokój, proszę czekać</translation>
    </message>
    <message>
        <source>Please fill the fields as desired. None are mandatory</source>
        <translation>Proszę wypełnić pola zgodnie z życzeniem. Żaden z nich nie jest obowiązkowy</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Applying changes, please wait</source>
        <translation>Wprowadzanie zmian, proszę czekać</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Login</source>
        <translation>Zaloguj się</translation>
    </message>
    <message>
        <source>Stay logged in</source>
        <translation>Pozostań zalogowany</translation>
    </message>
    <message>
        <source>Matrix ID</source>
        <translation>Identyfikator Matrix</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Device name</source>
        <translation>Nazwa urządzenia</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Połącz z serwerem</translation>
    </message>
    <message>
        <source>Connecting and logging in, please wait</source>
        <translation>Łączenie się i logowanie, proszę czekać</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Zaloguj ponownie</translation>
    </message>
    <message>
        <source>Restoring access, please wait</source>
        <translation>Przywracanie dostępu, proszę czekać</translation>
    </message>
    <message>
        <source>The homeserver is available</source>
        <translation>Serwer domowy jest dostępny</translation>
    </message>
    <message>
        <source>Could not connect to the homeserver</source>
        <translation>Nie można było się połączyć z serwerem domowym</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Loading...</source>
        <translation>Ładowanie…</translation>
    </message>
    <message>
        <source>&amp;Accounts</source>
        <translation>&amp;Konta</translation>
    </message>
    <message>
        <source>&amp;Login...</source>
        <translation>Zaloguj &amp;się…</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <source>&amp;Display in timeline</source>
        <translation>&amp;Pokaż na osi czasu</translation>
    </message>
    <message>
        <source>Normal &amp;join/leave events</source>
        <translation>&amp;Zwykłe zdarzenia dołączania/opuszczania</translation>
    </message>
    <message>
        <source>&amp;Redacted events</source>
        <translation>&amp;Zredagowane zdarzenia</translation>
    </message>
    <message>
        <source>Show redacted events in the timeline as &apos;Redacted&apos; instead of hiding them entirely</source>
        <translation>Pokaż zredagowane wydarzenia na osi czasu jako „Zredagowane”, zamiast całkowicie je ukrywać</translation>
    </message>
    <message>
        <source>&amp;No-effect activity</source>
        <translation>Aktywności &amp;bez efektu</translation>
    </message>
    <message>
        <source>Edit tags order</source>
        <translation>Edytuj kolejność tagów</translation>
    </message>
    <message>
        <source>&amp;Room</source>
        <translation>&amp;Pokój</translation>
    </message>
    <message>
        <source>Change room &amp;settings...</source>
        <translation>Zmień &amp;ustawienia pokoju…</translation>
    </message>
    <message>
        <source>Create &amp;new room...</source>
        <translation>Utwórz &amp;nowy pokój…</translation>
    </message>
    <message>
        <source>&amp;Join room...</source>
        <translation>&amp;Dołącz do pokoju…</translation>
    </message>
    <message>
        <source>&amp;Close current room</source>
        <translation>&amp;Zamknij bieżący pokój</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informacje o Quaternion</translation>
    </message>
    <message>
        <source>&amp;Highlight only</source>
        <translation>&amp;Tylko wyróżnij</translation>
    </message>
    <message>
        <source>Notifications are entirely suppressed</source>
        <translation>Powiadomienia są całkowicie tłumione</translation>
    </message>
    <message>
        <source>&amp;Non-intrusive</source>
        <translation>&amp;Nieinwazyjne</translation>
    </message>
    <message>
        <source>Show notifications but do not activate the window</source>
        <translation>Pokaż powiadomienia, ale nie aktywuj okna</translation>
    </message>
    <message>
        <source>&amp;Full</source>
        <translation>&amp;Pełne</translation>
    </message>
    <message>
        <source>Show notifications and activate the window</source>
        <translation>Pokaż powiadomienia i aktywuj okno</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślny</translation>
    </message>
    <message>
        <source>The layout with author labels above blocks of messages</source>
        <translation>Układ z etykietami autora nad blokami wiadomości</translation>
    </message>
    <message>
        <source>The layout with author labels to the left from each message</source>
        <translation>Układ z etykietami autora po lewej stronie przy każdej wiadomości</translation>
    </message>
    <message>
        <source>Timeline layout</source>
        <translation>Układ osi czasu</translation>
    </message>
    <message>
        <source>Load full-size images at once</source>
        <translation>Ładuj od razu pełnowymiarowe obrazy</translation>
    </message>
    <message>
        <source>Automatically download a full-size image instead of a thumbnail</source>
        <translation>Automatycznie pobierz obraz w pełnym rozmiarze zamiast miniatury</translation>
    </message>
    <message>
        <source>Configure &amp;network proxy...</source>
        <translation>&amp;Konfiguruj proxy sieciowe…</translation>
    </message>
    <message>
        <source>Logged out as %1</source>
        <translation>Wylogowano jako %1</translation>
    </message>
    <message>
        <source>Sync failed</source>
        <translation>Synchronizacja nie powiodła się</translation>
    </message>
    <message>
        <source>The last sync of account %1 has failed with error: %2</source>
        <translation>Ostatnia synchronizacja konta %1 nie powiodła się z powodu błędu: %2</translation>
    </message>
    <message>
        <source>The last sync has failed with error: %1</source>
        <translation>Ostatnia synchronizacja nie powiodła się z powodu błędu: %1</translation>
    </message>
    <message>
        <source>Clicking &apos;Retry&apos; will attempt to resume synchronisation;
Clicking &apos;Cancel&apos; will stop further synchronisation of this account until logout or Quaternion restart.</source>
        <translation>Kliknięcie „Ponów próbę” spowoduje wznowienie synchronizacji;
Kliknięcie „Anuluj” zatrzyma dalszą synchronizację tego konta do momentu wylogowania się lub ponownego uruchomienia Quaterniona.</translation>
    </message>
    <message>
        <source>Before this server can process your information, you have to agree with its terms and conditions; please click the button below to open the web page where you can do that</source>
        <translation>Zanim serwer ten będzie mógł przetwarzać Twoje informacje, musisz wyrazić zgodę na jego warunki; proszę kliknąć przycisk poniżej, aby otworzyć stronę internetową, na której możesz to zrobić</translation>
    </message>
    <message>
        <source>Open web page</source>
        <translation>Otwórz stronę internetową</translation>
    </message>
    <message>
        <source>About Quaternion</source>
        <translation>Informacje o Quaternion</translation>
    </message>
    <message>
        <source>Welcome to Quaternion</source>
        <translation>Witamy w Quaternion</translation>
    </message>
    <message>
        <source>Joined %1 as %2</source>
        <translation>Dołączono %1 jako %2</translation>
    </message>
    <message>
        <source>Couldn&apos;t connect to the server as %1; will retry within %2 seconds</source>
        <translation>Nie można było połączyć się z serwerem jako %1; spróbuje ponownie w ciągu %2 sekund</translation>
    </message>
    <message>
        <source>Reconnecting...</source>
        <translation>Ponowne łączenie…</translation>
    </message>
    <message>
        <source>No SSL support</source>
        <translation>Brak obsługi SSL</translation>
    </message>
    <message>
        <source>Your SSL configuration does not allow Quaternion to establish secure connections.</source>
        <translation>Twoja konfiguracja SSL nie zezwala Quaternionowi na ustanowienie bezpiecznych połączeń.</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>Błąd SSL</translation>
    </message>
    <message>
        <source>Proxy needs authentication</source>
        <translation>Proxy wymaga uwierzytelnienia</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Uwierzytelnij</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>&amp;Thanks</source>
        <translation>&amp;Podziękowania</translation>
    </message>
    <message>
        <source>Original project author: %1</source>
        <translation>Pierwotny autor projektu: %1</translation>
    </message>
    <message>
        <source>Web page</source>
        <translation>Strona internetowa</translation>
    </message>
    <message>
        <source>Project leader: %1</source>
        <translation>Kierownik projektu: %1</translation>
    </message>
    <message>
        <source>Contributors:</source>
        <translation>Współautorzy:</translation>
    </message>
    <message>
        <source>Quaternion contributors @ GitHub</source>
        <translation>Współautorzy Quaterniona na GitHubie</translation>
    </message>
    <message>
        <source>Quaternion translators @ Lokalise.co</source>
        <translation>Tłumacze Quaterniona w Lokalise.co</translation>
    </message>
    <message>
        <source>Made with:</source>
        <translation>Wykonana z:</translation>
    </message>
    <message>
        <source>Show join and leave events</source>
        <translation>Pokaż zdarzenia dołączenia i wyjścia</translation>
    </message>
    <message>
        <source>Request URL: %1
Response:
%2</source>
        <translation>Żądany adres URL: %1 
Odpowiedź: 
%2</translation>
    </message>
    <message>
        <source>Close to tray</source>
        <translation>Zamykaj do zasobnika</translation>
    </message>
    <message>
        <source>Make close button [X] minimize to tray instead of closing main window</source>
        <translation>Minimalizuje główne okno do zasobnika po wciśnięciu przycisku zamykania [X] zamiast zamykania go</translation>
    </message>
    <message>
        <source>Show/hide meaningless activity (join-leave pairs and redacted events between)</source>
        <translation>Pokaż/ukryj bezsensowną aktywność (pary dołączenia, opuszczenia i zredagowanych wydarzeń pomiędzy)</translation>
    </message>
    <message>
        <source>Built from Git, commit SHA:</source>
        <translation>Zbudowano z Git, commit SHA:</translation>
    </message>
    <message>
        <source>Library commit SHA:</source>
        <translation>Commit SHA biblioteki:</translation>
    </message>
    <message>
        <source>Open room...</source>
        <translation>Otwórz pokój…</translation>
    </message>
    <message>
        <source>Open room</source>
        <translation>Otwórz pokój</translation>
    </message>
    <message>
        <source>Open a room from the room list</source>
        <translation>Otwórz pokój z listy pokoi</translation>
    </message>
    <message>
        <source>Couldn&apos;t delete access token</source>
        <translation>Nie można usunąć tokena dostępu</translation>
    </message>
    <message>
        <source>Open direct chat?</source>
        <translation>Otworzyć bezpośrednią rozmowę?</translation>
    </message>
    <message>
        <source>Open direct chat with user %1?</source>
        <translation>Otworzyć bezpośrednią rozmowę z użytkownikiem %1?</translation>
    </message>
    <message>
        <source>Room not found</source>
        <translation>Nie znaleziono pokoju</translation>
    </message>
    <message>
        <source>There&apos;s no room %1 in the room list. Check the spelling and the account.</source>
        <translation>Nie ma pokoju %1 na liście pokoi. Sprawdź pisownię i konto.</translation>
    </message>
    <message>
        <source>Confirm your account to open %1</source>
        <translation>Potwierdź twoje konto, aby otworzyć %1</translation>
    </message>
    <message>
        <source>Confirm account</source>
        <translation>Potwierdź konto</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Room ID (starting with !)
or alias (starting with #)</source>
        <translation>Identyfikator pokoju (zaczynający się od !) 
lub alias (zaczynający się od #)</translation>
    </message>
    <message>
        <source>Confirm account to join %1</source>
        <translation>Potwierdź konto, aby dołączyć do %1</translation>
    </message>
    <message>
        <source>Edit quote style</source>
        <translation>Edytuj styl cytowania</translation>
    </message>
    <message>
        <source>Markdown (prepend each line with &gt;)</source>
        <translation>Markdown (poprzedzaj każdą linię &gt;)</translation>
    </message>
    <message>
        <source>Custom (apply regex from the config file)</source>
        <translation>Niestandardowy (zastosuj wyrażenie regularne z pliku konfiguracyjnego)</translation>
    </message>
    <message>
        <source>Locale&apos;s default (%1)</source>
        <translation>Domyślne ustawienia regionalne (%1)</translation>
    </message>
    <message>
        <source>Example quote</source>
        <translation>Przykładowy cytat</translation>
    </message>
    <message>
        <source>Choose the default style of quotes</source>
        <translation>Wybierz domyślny styl cytatów</translation>
    </message>
    <message>
        <source>Special thanks to %1 for all the testing effort</source>
        <translation>Specjalne podziękowania dla %1 za cały wysiłek włożony w testowanie.</translation>
    </message>
    <message>
        <source>libQuotient contributors @ GitHub</source>
        <translation>Współautorzy libQuotient na GitHubie</translation>
    </message>
    <message>
        <source>First sync completed for %1</source>
        <translation>Pierwsza synchronizacja dla %1 zakończona</translation>
    </message>
    <message>
        <source>Quaternion couldn&apos;t delete the access token from the keychain.</source>
        <translation>Quaternion nie mógł usunąć tokena dostępu z pęku kluczy.</translation>
    </message>
    <message>
        <source>No application for the link</source>
        <translation>Nie znaleziono aplikacji mogącą otworzyć link</translation>
    </message>
    <message>
        <source>External link confirmation</source>
        <translation>Potwierdzenie odnośnika zewnętrznego</translation>
    </message>
    <message>
        <source>An external application will be opened to visit a non-Matrix link:

%1

Is that right?</source>
        <translation>Otworzy się zewnętrzna aplikacja, aby odwiedzić odnośnik inny niż Matrix: 

%1 

Czy to się zgadza?</translation>
    </message>
    <message>
        <source>Do not ask again</source>
        <translation>Nie pytaj ponownie</translation>
    </message>
    <message>
        <source>Malformed or empty Matrix id</source>
        <translation>Nieprawidłowy lub pusty identyfikator Matrixa</translation>
    </message>
    <message>
        <source>%1 is not a correct Matrix identifier</source>
        <translation>%1 nie jest prawidłowym identyfikatorem Matrixa</translation>
    </message>
    <message>
        <source>Please connect to a server</source>
        <translation>Połącz się z serwerem</translation>
    </message>
    <message>
        <source>User &amp;profiles...</source>
        <translation>Profile &amp;użytkowników…</translation>
    </message>
    <message>
        <source>Log&amp;out</source>
        <translation>Wyl&amp;oguj</translation>
    </message>
    <message>
        <source>Invite events</source>
        <translation>Wydarzenia zaproszeń</translation>
    </message>
    <message>
        <source>Show invite and withdrawn invitation events</source>
        <translation>Pokazuj zdarzenia zaproszeń i odrzucenia zaproszeń</translation>
    </message>
    <message>
        <source>Changes in display na&amp;me</source>
        <translation>Z&amp;miany w wyświetlanej nazwie</translation>
    </message>
    <message>
        <source>Show display name change</source>
        <translation>Pokazuj zmianę wyświetlanej nazwy</translation>
    </message>
    <message>
        <source>Avatar &amp;changes</source>
        <translation>Zmiany &amp;awatara</translation>
    </message>
    <message>
        <source>Show avatar update events</source>
        <translation>Pokazuj zdarzenia aktualizacji awatara</translation>
    </message>
    <message>
        <source>Room alias &amp;updates</source>
        <translation>Aktualizacje aliasu pokoju</translation>
    </message>
    <message>
        <source>Show room alias updates events</source>
        <translation>Pokazuj zdarzenia aktualizacji aliasu serwera</translation>
    </message>
    <message>
        <source>Un&amp;known event types</source>
        <translation>&amp;Nieznane typy wydarzeń</translation>
    </message>
    <message>
        <source>Show/hide unknown event types</source>
        <translation>Pokazuj/ukrywaj nieznane typy zdarzeń</translation>
    </message>
    <message>
        <source>Tags can be wildcarded by * next to dot(s)
Clear the box to reset to defaults
Special tags starting with &quot;im.quotient.&quot; are: %1
User-defined tags should start with &quot;u.&quot;</source>
        <translation>Tagi mogą być wieloznaczne przez * obok kropek
Wyczyść pole, aby przywrócić domyślne ustawienia
Specjalne tagi zaczynające się od „im.quotient.” to: %1
Tagi zdefiniowane przez użytkownika powinny zaczynać się od „u.”</translation>
    </message>
    <message>
        <source>&amp;About Quaternion</source>
        <translation>&amp;Informacje o Quaternion</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informacje o &amp;Qt</translation>
    </message>
    <message>
        <source>Use Breeze style (requires restart)</source>
        <translation>Użyj stylu Breeze (wymaga ponownego uruchomienia)</translation>
    </message>
    <message>
        <source>Force use Breeze style and icon theme</source>
        <translation>Wymuś użycie stylu i motywu ikon Breeze</translation>
    </message>
    <message>
        <source>Chat with user</source>
        <translation>Czatuj z użytkownikiem</translation>
    </message>
    <message>
        <source>Can&apos;t open</source>
        <translation>Nie można otworzyć</translation>
    </message>
    <message>
        <source>Could not resolve id</source>
        <translation>Nie można ustalić identyfikatora</translation>
    </message>
    <message>
        <source>Could not find an external application to open the URI:</source>
        <translation>Nie udało się znaleźć zewnętrznej aplikacji do otwarcia identyfikatora URI:</translation>
    </message>
    <message>
        <source>Could not resolve Matrix identifier</source>
        <translation>Nie można ustalić identyfikatora Matrix</translation>
    </message>
    <message>
        <source>Room or user ID, room alias,
Matrix URI or matrix.to link</source>
        <translation>ID pokoju lub użytkownika, alias pokoju, 
Matrix URI lub link matrix.to</translation>
    </message>
    <message>
        <source>Go to room</source>
        <translation>Przejdź do pokoju</translation>
    </message>
    <message>
        <source>Join room</source>
        <translation>Dołącz do pokoju</translation>
    </message>
    <message>
        <source>Quaternion project contributors</source>
        <translation>Współautorzy projektu Quaternion</translation>
    </message>
    <message>
        <source>Felix Rohrbach</source>
        <translation>Felix Rohrbach</translation>
    </message>
    <message>
        <source>Alexey &quot;Kitsune&quot; Rusakov</source>
        <translation>Alexey &quot;Kitsune&quot; Rusakov</translation>
    </message>
    <message>
        <source>Confirm opening external links</source>
        <translation>Potwierdzaj otwieranie linków zewnętrznych</translation>
    </message>
    <message>
        <source>Show a confirmation box before opening non-Matrix links in an external application</source>
        <translation>Pokazuj okno potwierdzenia przed otwarciem linków innych niż Matrix w zewnętrznej aplikacji</translation>
    </message>
</context>
<context>
    <name>MessageEventModel</name>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
    <message>
        <source>Yesterday</source>
        <translation>Wczoraj</translation>
    </message>
    <message>
        <source>The day before yesterday</source>
        <translation>Przedwczoraj</translation>
    </message>
    <message>
        <source>Redacted</source>
        <translation>Zredagowano</translation>
    </message>
    <message>
        <source>Redacted: %1</source>
        <translation>zredagował(a): %1</translation>
    </message>
    <message>
        <source>a file</source>
        <translation>plik</translation>
    </message>
    <message>
        <source>invited %1 to the room</source>
        <translation>zaprosił(a) %1 do pokoju</translation>
    </message>
    <message>
        <source>joined the room</source>
        <translation>dołączył(a) do pokoju</translation>
    </message>
    <message>
        <source>cleared the display name</source>
        <translation>wyczyścił(a) swoją wyświetlaną nazwę</translation>
    </message>
    <message>
        <source>changed the display name to %1</source>
        <translation>zmienił(a) swoją wyświetlaną nazwę na %1</translation>
    </message>
    <message>
        <source>cleared the avatar</source>
        <translation>wyczyścił(a) awatar</translation>
    </message>
    <message>
        <source>updated the avatar</source>
        <translation>zaktualizował(a) awatar</translation>
    </message>
    <message>
        <source>unbanned %1</source>
        <translation>odbanował(a) %1</translation>
    </message>
    <message>
        <source>left the room</source>
        <translation>opuścił(a) pokój</translation>
    </message>
    <message>
        <source>knocked</source>
        <translation>zapukał</translation>
    </message>
    <message>
        <source>made something unknown</source>
        <translation>zrobił(a) coś nieznanego</translation>
    </message>
    <message>
        <source>cleared the room main alias</source>
        <translation>wyczyścił(a) główny alias pokoju</translation>
    </message>
    <message>
        <source>set the room main alias to: %1</source>
        <translation>ustawił(a) główny alias pokoju na: %1</translation>
    </message>
    <message>
        <source>cleared the room name</source>
        <translation>wyczyścił(a) nazwę pokoju</translation>
    </message>
    <message>
        <source>set the room name to: %1</source>
        <translation>ustawił(a) nazwę pokoju na %1</translation>
    </message>
    <message>
        <source>cleared the topic</source>
        <translation>wyczyścił(a) temat</translation>
    </message>
    <message>
        <source>set the topic to: %1</source>
        <translation>ustawił(a) temat na %1</translation>
    </message>
    <message>
        <source>changed the room avatar</source>
        <translation>zmienił(a) awatar pokoju</translation>
    </message>
    <message>
        <source>activated End-to-End Encryption</source>
        <translation>aktywował(a) szyfrowanie End-to-End</translation>
    </message>
    <message>
        <source>withdrew %1&apos;s invitation</source>
        <translation>wycofał(a) zaproszenie %1</translation>
    </message>
    <message>
        <source>rejected the invitation</source>
        <translation>odrzucił(a) zaproszenie</translation>
    </message>
    <message>
        <source>updated the database</source>
        <translation>zaktualizował bazę danych</translation>
    </message>
    <message>
        <source>updated %1 state</source>
        <translation>zaktualizował(a) stan %1</translation>
    </message>
    <message>
        <source>updated %1 state for %2</source>
        <translation>zaktualizował(a) stan %1 dla %2</translation>
    </message>
    <message>
        <source>Unknown event</source>
        <translation>Nieznane zdarzenie</translation>
    </message>
    <message>
        <source>upgraded the room to version %1</source>
        <translation>zaktualizował(a) pokój do wersji %1</translation>
    </message>
    <message>
        <source>created the room, version %1</source>
        <translation>stworzył(a) pokój, wersja %1</translation>
    </message>
    <message>
        <source>banned %1 from the room: %2</source>
        <translation>zbanował(a) %1 z pokoju: %2</translation>
    </message>
    <message>
        <source>kicked %1 from the room: %2</source>
        <translation>wyrzucił(-a) %1 z pokoju: %2</translation>
    </message>
    <message>
        <source>upgraded the room: %1</source>
        <translation>zaktualizował(-a) pokój: %1</translation>
    </message>
    <message>
        <source> and </source>
        <translation> i </translation>
    </message>
    <message numerus="yes">
        <source>%Ln more member(s)</source>
        <translation>
            <numerusform>%Ln użytkownika więcej</numerusform>
            <numerusform>%Ln użytkowników więcej</numerusform>
            <numerusform>%Ln użytkowników więcej</numerusform>
            <numerusform>%Ln użytkowników więcej</numerusform>
        </translation>
    </message>
    <message>
        <source>(repeated)</source>
        <translation>(powtórzono)</translation>
    </message>
    <message>
        <source>kicked %1 from the room</source>
        <translation>wyrzucił(-a) %1 z pokoju</translation>
    </message>
</context>
<context>
    <name>NetworkConfigDialog</name>
    <message>
        <source>Network proxy settings</source>
        <translation>Ustawienia proxy sieciowego</translation>
    </message>
    <message>
        <source>&amp;Override system defaults</source>
        <translation>&amp;Nadpisz domyślne ustawienia systemowe</translation>
    </message>
    <message>
        <source>&amp;No proxy</source>
        <translation>&amp;Bez proxy</translation>
    </message>
    <message>
        <source>&amp;HTTP(S) proxy</source>
        <translation>&amp;HTTP(S) proxy</translation>
    </message>
    <message>
        <source>&amp;SOCKS5 proxy</source>
        <translation>&amp;SOCKS5 proxy</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Nazwa użytkownika</translation>
    </message>
</context>
<context>
    <name>RoomDialogBase</name>
    <message>
        <source>Publish room in room directory</source>
        <translation>Opublikuj pokój w katalogu pokoju</translation>
    </message>
    <message>
        <source>Allow guest accounts to join the room</source>
        <translation>Zezwalaj kontom gości na dołączenie do pokoju</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Room name</source>
        <translation>Nazwa pokoju</translation>
    </message>
    <message>
        <source>Primary alias</source>
        <translation>Główny alias</translation>
    </message>
    <message>
        <source>Topic</source>
        <translation>Temat</translation>
    </message>
    <message>
        <source>About room versions</source>
        <translation>O wersjach pokoi</translation>
    </message>
    <message>
        <source>(loading)</source>
        <translation>(ładowanie)</translation>
    </message>
    <message>
        <source>default</source>
        <translation>domyślna</translation>
    </message>
    <message>
        <source>stable</source>
        <translation>stabilna</translation>
    </message>
    <message>
        <source>Room version</source>
        <translation>Wersja pokoju</translation>
    </message>
    <message>
        <source>Continue with unstable version?</source>
        <translation>Kontynuować z niestabilną wersją?</translation>
    </message>
    <message>
        <source>You are using an UNSTABLE room version (%1). The server may stop supporting it at any moment. Do you still want to use this version?</source>
        <translation>Używasz NIESTABILNEJ wersji pokoju (%1). Serwer może przestać go obsługiwać w każdej chwili. Czy nadal chcesz używać tej wersji?</translation>
    </message>
</context>
<context>
    <name>RoomListDock</name>
    <message>
        <source>Mark room as read</source>
        <translation>Oznacz pokój jako przeczytany</translation>
    </message>
    <message>
        <source>Add tags...</source>
        <translation>Dodaj tagi…</translation>
    </message>
    <message>
        <source>Join room</source>
        <translation>Dołącz do pokoju</translation>
    </message>
    <message>
        <source>Forget room</source>
        <translation>Zapomnij pokój</translation>
    </message>
    <message>
        <source>Remove tag</source>
        <translation>Usuń tag</translation>
    </message>
    <message>
        <source>Reject invitation</source>
        <translation>Odrzuć zaproszenie</translation>
    </message>
    <message>
        <source>Leave room</source>
        <translation>Opuść pokój</translation>
    </message>
    <message>
        <source>Enter new tags for the room</source>
        <translation>Wprowadź nowe tagi dla pokoju</translation>
    </message>
    <message>
        <source>Enter tags to add to this room, one tag per line</source>
        <translation>Wprowadź nowe tagi dla pokoju, jeden tag na linię</translation>
    </message>
    <message>
        <source>Change room &amp;settings...</source>
        <translation>Zmień &amp;ustawienia pokoju…</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Copy room link to clipboard</source>
        <translation>Skopiuj link do pokoju do schowka</translation>
    </message>
    <message>
        <source>Rooms (%L1)</source>
        <translation>Pokoje (%L1)</translation>
    </message>
</context>
<context>
    <name>RoomListModel</name>
    <message>
        <source>Invited</source>
        <translation>Zaproszone</translation>
    </message>
    <message>
        <source>Low priority</source>
        <translation>Niski priorytet</translation>
    </message>
    <message>
        <source>People</source>
        <translation>Ludzie</translation>
    </message>
    <message>
        <source>Ungrouped rooms</source>
        <translation>Niezgrupowane pokoje</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Opuszczone</translation>
    </message>
    <message numerus="yes">
        <source>%1 (%Ln room(s))</source>
        <translation>
            <numerusform>%1 (%Ln pokój)</numerusform>
            <numerusform>%1 (%Ln pokoje)</numerusform>
            <numerusform>%1 (%Ln pokojów)</numerusform>
            <numerusform>%1 (%Ln pokojów)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 (as %2)</source>
        <translation>%1 (jako %2)</translation>
    </message>
    <message>
        <source>Main alias: %1</source>
        <translation>Główny alias: %1</translation>
    </message>
    <message>
        <source>Direct chat with %1</source>
        <translation>Bezpośrednia rozmowa z %1</translation>
    </message>
    <message>
        <source>The room enforces encryption</source>
        <translation>Ten pokój wymusza szyfrowanie</translation>
    </message>
    <message>
        <source>Favourites</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>This room&apos;s version is unstable!</source>
        <translation>Wersja tego pokoju jest niestabilna!</translation>
    </message>
    <message>
        <source>Server notices</source>
        <translation>Ogłoszenia serwera</translation>
    </message>
    <message>
        <source>Joined: %L1</source>
        <translation>Dołączeni: %L1</translation>
    </message>
    <message>
        <source>Invited: %L1</source>
        <translation>Zaproszone: %L1</translation>
    </message>
    <message>
        <source>(maybe more)</source>
        <translation>(możliwie więcej)</translation>
    </message>
</context>
<context>
    <name>RoomSettingsDialog</name>
    <message>
        <source>Room settings: %1</source>
        <translation>Ustawienia pokoju: %1</translation>
    </message>
    <message>
        <source>Update room</source>
        <translation>Zaktualizuj pokój</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Tagi</translation>
    </message>
    <message>
        <source>This version is unstable! Consider upgrading.</source>
        <translation>Ta wersja jest niestabilna! Rozważ aktualizację.</translation>
    </message>
    <message>
        <source>Upgrade</source>
        <translation>Zaktualizuj</translation>
    </message>
    <message>
        <source>Choose new room version</source>
        <translation>Wybierz nową wersję pokoju</translation>
    </message>
    <message>
        <source>You are about to upgrade %1.
This operation cannot be reverted.</source>
        <translation>Zamierzasz zaktualizować %1. 
Ta operacja nie może zostać cofnięta.</translation>
    </message>
    <message>
        <source>Creating the new room version, please wait</source>
        <translation>Tworzenie nowej wersji pokoju, proszę czekać</translation>
    </message>
    <message>
        <source>Room identifier</source>
        <translation>Identyfikator pokoju</translation>
    </message>
</context>
<context>
    <name>UserListDock</name>
    <message>
        <source>Users</source>
        <translation>Użytkownicy</translation>
    </message>
    <message>
        <source>Open direct chat</source>
        <translation>Otwórz bezpośredni czat</translation>
    </message>
    <message>
        <source>Mention user</source>
        <translation>Wspomnij użytkownika</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Ignore user</source>
        <translation>Ignoruj użytkownika</translation>
    </message>
    <message>
        <source>Kick user</source>
        <translation>Wyrzuć użytkownika</translation>
    </message>
    <message>
        <source>Ban user</source>
        <translation>Banuj użytkownika</translation>
    </message>
    <message>
        <source>Kick %1</source>
        <translation>Wyrzuć %1</translation>
    </message>
    <message>
        <source>Reason</source>
        <translation>Powód</translation>
    </message>
    <message>
        <source>Ban %1</source>
        <translation>Banuj %1</translation>
    </message>
    <message>
        <source>(%L1 out of %L2)</source>
        <translation>(%L1 z %L2)</translation>
    </message>
</context>
<context>
    <name>FileContent</name>
    <message>
        <source>Size: %1, declared type: %2</source>
        <translation>Rozmiar: %1, zadeklarowany typ: %2</translation>
    </message>
    <message>
        <source>Open after downloading</source>
        <translation>Otwórz po pobraniu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Zapisz jako…</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otwórz folder</translation>
    </message>
    <message>
        <source>uploaded from %1</source>
        <translation>przesłany z %1</translation>
    </message>
    <message>
        <source>downloaded to %1</source>
        <translation>pobrano do %1</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
    <message>
        <source>%L1 kB</source>
        <translation>%L1 kB</translation>
    </message>
    <message>
        <source>%L1 MB</source>
        <translation>%L1 MB</translation>
    </message>
    <message>
        <source>%L1 GB</source>
        <translation>%L1 GB</translation>
    </message>
</context>
<context>
    <name>TimelineItem</name>
    <message>
        <source>Resend</source>
        <translation>Wyślij ponownie</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>Odrzuć</translation>
    </message>
    <message>
        <source>edited</source>
        <translation>edytowane</translation>
    </message>
    <message>
        <source>Go to
older room</source>
        <translation>Przejdź do
starszego pokoju</translation>
    </message>
    <message>
        <source>Go to
new room</source>
        <translation>Przejdź do
nowego pokoju</translation>
    </message>
    <message>
        <source>Reaction &apos;%1&apos; from %2</source>
        <translation>Reakcja „%1” od %2</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Quaternion - an IM client for the Matrix protocol</source>
        <translation>Quaternion - komunikator internetowy dla protokołu Matrix</translation>
    </message>
    <message>
        <source>Override locale</source>
        <translation>Nadpisz ustawienia regionalne</translation>
    </message>
    <message>
        <source>locale</source>
        <translation>locale</translation>
    </message>
    <message>
        <source>Hide main window on startup</source>
        <translation>Ukryj główne okno podczas uruchamiania</translation>
    </message>
</context>
<context>
    <name>SystemTrayIcon</name>
    <message>
        <source>Highlight in %1</source>
        <translation>Podświetlenie w %1</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ukryj</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Pokaż</translation>
    </message>
    <message numerus="yes">
        <source>%Ln highlight(s)</source>
        <translation>
            <numerusform>%Ln wyróżnienie</numerusform>
            <numerusform>%Ln wyróżnienia</numerusform>
            <numerusform>%Ln wyróżnień</numerusform>
            <numerusform>%Ln wyróżnień</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TimelineWidget</name>
    <message>
        <source>Referenced message not found</source>
        <translation>Nie znaleziono odwołanej wiadomości</translation>
    </message>
    <message>
        <source>Copy permalink to clipboard</source>
        <translation>Skopiuj link bezpośredni do schowka</translation>
    </message>
    <message>
        <source>Show details</source>
        <translation>Pokaż szczegóły</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Otwórz folder</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Save file as...</source>
        <translation>Zapisz plik jako…</translation>
    </message>
    <message>
        <source>Copy selected text to clipboard</source>
        <translation>Skopiuj zaznaczony tekst do schowka</translation>
    </message>
    <message>
        <source>Copy image to clipboard</source>
        <translation>Skopiuj obraz do schowka</translation>
    </message>
    <message>
        <source>Save file as</source>
        <translation>Zapisz plik jako</translation>
    </message>
    <message>
        <source>Redact</source>
        <translation>Zredaguj</translation>
    </message>
    <message>
        <source>Copy link to clipboard</source>
        <translation>Skopiuj link do schowka</translation>
    </message>
    <message>
        <source>Quote</source>
        <translation>Cytuj</translation>
    </message>
    <message>
        <source>Open externally</source>
        <translation>Otwórz zewnętrznie</translation>
    </message>
</context>
<context>
    <name>ProfileDialog</name>
    <message>
        <source>Device display name</source>
        <translation>Wyświetlana nazwa urządzenia</translation>
    </message>
    <message>
        <source>Device ID</source>
        <translation>Identyfikator urządzenia</translation>
    </message>
    <message>
        <source>Last time seen</source>
        <translation>Ostatnio widziany</translation>
    </message>
    <message>
        <source>Last IP address</source>
        <translation>Ostatni adres IP</translation>
    </message>
    <message>
        <source>User profiles</source>
        <translation>Profile użytkowników</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Display Name</source>
        <translation>Wyświetlana nazwa</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Skopiuj do schowka</translation>
    </message>
    <message>
        <source>Access token</source>
        <translation>Token dostępu</translation>
    </message>
    <message>
        <source>Loading other devices...</source>
        <translation>Ładowanie innych urządzeń…</translation>
    </message>
    <message>
        <source>No avatar</source>
        <translation>Brak awatara</translation>
    </message>
    <message>
        <source>Set avatar</source>
        <translation>Ustaw awatar</translation>
    </message>
</context>
<context>
    <name>Timeline</name>
    <message>
        <source>Latest events</source>
        <translation>Ostatnie wydarzenia</translation>
    </message>
    <message numerus="yes">
        <source>%Ln events back from now</source>
        <translation>
            <numerusform>%Ln wydarzenie od teraz</numerusform>
            <numerusform>%Ln wydarzenia od teraz</numerusform>
            <numerusform>%Ln wydarzeń od teraz</numerusform>
            <numerusform>%Ln wydarzeń od teraz</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln events cached</source>
        <translation>
            <numerusform>%Ln wydarzenie w pamięci podręcznej</numerusform>
            <numerusform>%Ln wydarzenia w pamięci podręcznej</numerusform>
            <numerusform>%Ln wydarzeń w pamięci podręcznej</numerusform>
            <numerusform>%Ln wydarzeń w pamięci podręcznej</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ChatEdit</name>
    <message>
        <source>Reset formatting</source>
        <translation>Zresetuj formatowanie</translation>
    </message>
    <message>
        <source>Reset the current character formatting to the default</source>
        <translation>Przywraca domyślne formatowanie znaków</translation>
    </message>
</context>
<context>
    <name>RoomHeader</name>
    <message>
        <source>(no name)</source>
        <translation>(bez nazwy)</translation>
    </message>
    <message>
        <source>This room has been upgraded.</source>
        <translation>Ten pokój został zaktualizowany.</translation>
    </message>
    <message>
        <source>Unstable room version!</source>
        <translation>Niestabilna wersja pokoju!</translation>
    </message>
    <message>
        <source>(no topic)</source>
        <translation>(brak tematu)</translation>
    </message>
    <message>
        <source>Hide topic</source>
        <translation>Ukryj temat</translation>
    </message>
    <message>
        <source>Show topic</source>
        <translation>Pokaż temat</translation>
    </message>
    <message>
        <source>Room
settings</source>
        <translation>Ustawienia
pokoju</translation>
    </message>
    <message>
        <source>Go to
new room</source>
        <translation>Przejdź do
nowego pokoju</translation>
    </message>
</context>
</TS>
